#ifndef _PERIPHERALS_H_
#define _PERIPHERALS_H_

#include <stdint.h>
#include <stdbool.h>
#include <string.h>
#include "nordic_common.h"
#include "nrf.h"
#include "boards.h"
#include "nrf_gpio.h"
#include "nrf_delay.h"
#include "nrf_drv_spi.h"
#include "nrf_drv_twi.h"
#include "nrf_drv_ppi.h"
#include "nrf_drv_timer.h"
#include "nrf_drv_saadc.h"

#include "app_timer.h"
#include "app_util_platform.h"
#include "app_error.h"

#ifndef SPI_USE_INTERRUPT
#define	SPI_USE_INTERRUPT   0
#endif

#ifndef TWI_USE_INTERRUPT
#define	TWI_USE_INTERRUPT   1
#endif

#define ADC_ACQUISITION_INTERVAL        MSEC_TO_UNITS(10, UNIT_1_25_MS)             /**< ADC acquisition interval (ticks).           */
#define BATTERY_LEVEL_MEAS_INTERVAL     10000                                       /**< Battery level measurement interval (ticks). */
         
#define SAADC_CALIBRATION_INTERVAL      64

/* TWI instances */
extern const nrf_drv_twi_t m_eeprom_twi;

/* SPI instances */
extern const nrf_drv_spi_t m_oled_spi;

/* SAADC variables */
extern uint32_t m_saadc_evt_counter;
extern bool     m_saadc_calibrate;

#if TWI_USE_INTERRUPT
extern void eeprom_callback(nrf_drv_twi_evt_t const *p_event, void *p_context);
#endif

#if SPI_USE_INTERRUPT
extern void oled_spi_callback(nrf_drv_spi_evt_t const *p_event, void *p_context);
#endif

void saadc_init(nrf_drv_saadc_event_handler_t battery_event_handler);
void twi_init(void);
void spi_init(void);
void timers_init(nrfx_timer_event_handler_t saadc_timer, nrfx_timer_event_handler_t battery_timer_handler);

void saadc_set_buffer(void);
void saadc_sampling_event_init(void);
void saadc_sampling_event_enable(void);
void saadc_wait_calibration(void);

#endif /* _PERIPHERALS_H_ */